NetworkingClient

Struct NetworkingClient 

pub struct NetworkingClient<'a> { /* private fields */ }
Client for the Azure Networking API.

Wraps the raw NetworkingOps with ergonomic signatures that auto-inject subscription_id from the parent AzureHttpClient.

Implementations

Source

impl<'a> NetworkingClient<'a>

pub async fn list_vnets( &self, resource_group_name: &str, ) -> Result<VirtualNetworkListResult>

Gets all virtual networks in a resource group.

pub async fn list_vnets_all(&self) -> Result<VirtualNetworkListResult>

Gets all virtual networks in the subscription.

pub async fn get_vnet( &self, resource_group_name: &str, vnet_name: &str, ) -> Result<VirtualNetwork>

Gets the specified virtual network.

pub async fn create_vnet( &self, resource_group_name: &str, vnet_name: &str, body: &VirtualNetworkCreateRequest, ) -> Result<VirtualNetwork>

Creates or updates a virtual network.

pub async fn delete_vnet( &self, resource_group_name: &str, vnet_name: &str, ) -> Result<()>

Deletes the specified virtual network.

pub async fn list_subnets( &self, resource_group_name: &str, vnet_name: &str, ) -> Result<SubnetListResult>

Gets all subnets in a virtual network.

pub async fn get_subnet( &self, resource_group_name: &str, vnet_name: &str, subnet_name: &str, ) -> Result<Subnet>

Gets the specified subnet.

pub async fn list_nsgs( &self, resource_group_name: &str, ) -> Result<NetworkSecurityGroupListResult>

Gets all network security groups in a resource group.

pub async fn list_nsgs_all(&self) -> Result<NetworkSecurityGroupListResult>

Gets all network security groups in the subscription.

pub async fn get_nsg( &self, resource_group_name: &str, nsg_name: &str, ) -> Result<NetworkSecurityGroup>

Gets the specified network security group.

pub async fn create_nsg( &self, resource_group_name: &str, nsg_name: &str, body: &NetworkSecurityGroupCreateRequest, ) -> Result<NetworkSecurityGroup>

Creates or updates a network security group.

pub async fn delete_nsg( &self, resource_group_name: &str, nsg_name: &str, ) -> Result<()>

Deletes the specified network security group.

pub async fn list_security_rules( &self, resource_group_name: &str, nsg_name: &str, ) -> Result<SecurityRuleListResult>

Gets all security rules in a network security group.

pub async fn get_security_rule( &self, resource_group_name: &str, nsg_name: &str, rule_name: &str, ) -> Result<SecurityRule>

Gets the specified network security rule.

pub async fn create_security_rule( &self, resource_group_name: &str, nsg_name: &str, rule_name: &str, body: &SecurityRule, ) -> Result<SecurityRule>

Creates or updates a security rule in a network security group.

pub async fn delete_security_rule( &self, resource_group_name: &str, nsg_name: &str, rule_name: &str, ) -> Result<()>

Deletes the specified network security rule.

pub async fn list_load_balancers( &self, resource_group_name: &str, ) -> Result<LoadBalancerListResult>

Gets all the load balancers in a resource group.

pub async fn list_load_balancers_all(&self) -> Result<LoadBalancerListResult>

Gets all the load balancers in the subscription.

pub async fn get_load_balancer( &self, resource_group_name: &str, lb_name: &str, ) -> Result<LoadBalancer>

Gets the specified load balancer.

pub async fn create_load_balancer( &self, resource_group_name: &str, lb_name: &str, body: &LoadBalancerCreateRequest, ) -> Result<LoadBalancer>

Creates or updates a load balancer.

pub async fn delete_load_balancer( &self, resource_group_name: &str, lb_name: &str, ) -> Result<()>

Deletes the specified load balancer.

pub async fn delete_network_interface( &self, resource_group_name: &str, nic_name: &str, ) -> Result<()>

Deletes the specified network interface.

pub async fn delete_nat_gateway( &self, resource_group_name: &str, nat_gateway_name: &str, ) -> Result<()>

Deletes the specified NAT gateway.