AzureHttpClient

Struct AzureHttpClient 

pub struct AzureHttpClient { /* private fields */ }
HTTP client for Azure API operations.

Provides automatic Bearer token injection, retry, and rate limiting.

Implementations

Source

impl AzureHttpClient

pub fn builder() -> AzureHttpClientBuilder

Create a new builder.

pub async fn from_env() -> Result<Self, AzureError>

Create a client using the default credential chain.

Resolves credentials in order:

  1. Service principal env vars
  2. Managed identity IMDS
  3. Azure CLI
pub fn subscription_id(&self) -> &str

Get the configured subscription ID.

pub async fn token(&self) -> Result<String, AzureError>

Acquire a token from the credential chain.

pub fn acr(&self) -> AcrClient<'_>

Access the Azure Container Registry API

pub fn aks(&self) -> AksClient<'_>

Access the Azure Kubernetes Service API

pub fn compute(&self) -> ComputeClient<'_>

Access the Azure Compute API

pub fn cosmosdb(&self) -> CosmosDbClient<'_>

Access the Azure CosmosDB API

pub fn cost(&self) -> CostClient<'_>

Access the Azure Cost Management API

pub fn dns(&self) -> DnsClient<'_>

Access the Azure DNS API

pub fn functions(&self) -> FunctionsClient<'_>

Access the Azure Functions API

pub fn graph(&self) -> GraphClient<'_>

Access the Microsoft Graph API

pub fn identity(&self) -> IdentityClient<'_>

Access the Azure Managed Identities API

pub fn keyvault(&self) -> KeyVaultClient<'_>

Access the Azure Key Vault API

pub fn log_analytics(&self) -> LogAnalyticsClient<'_>

Access the Azure Log Analytics API

pub fn monitor(&self) -> MonitorClient<'_>

Access the Azure Monitor API

pub fn networking(&self) -> NetworkingClient<'_>

Access the Azure Networking API

pub fn rbac(&self) -> RbacClient<'_>

Access the Azure RBAC API

pub fn redis(&self) -> RedisClient<'_>

Access the Azure Redis Cache API

pub fn resource_graph(&self) -> ResourceGraphClient<'_>

Access the Azure Resource Graph API

pub fn security(&self) -> SecurityClient<'_>

Access the Azure Defender for Cloud API

pub fn sql(&self) -> SqlClient<'_>

Access the Azure SQL API

pub fn storage(&self) -> StorageClient<'_>

Access the Azure Storage API

pub fn subscriptions(&self) -> SubscriptionsClient<'_>

Access the Azure Subscriptions API

pub async fn get(&self, url: &str) -> Result<AzureResponse, AzureError>

Make a GET request with automatic Bearer token injection and retry.

pub async fn put( &self, url: &str, body: &[u8], ) -> Result<AzureResponse, AzureError>

Make a PUT request with a JSON body.

pub async fn post( &self, url: &str, body: &[u8], ) -> Result<AzureResponse, AzureError>

Make a POST request with a JSON body.

pub async fn delete(&self, url: &str) -> Result<AzureResponse, AzureError>

Make a DELETE request.

pub async fn patch( &self, url: &str, body: &[u8], ) -> Result<AzureResponse, AzureError>

Make a PATCH request with a JSON body.