pub struct NetworkingClient<'a> { /* private fields */ }Expand description
Client for the Azure Networking API.
Wraps the raw NetworkingOps with ergonomic signatures that
auto-inject subscription_id from the parent AzureHttpClient.
Implementations
Sourceimpl<'a> NetworkingClient<'a>
impl<'a> NetworkingClient<'a>
Sourcepub async fn list_vnets(
&self,
resource_group_name: &str,
) -> Result<VirtualNetworkListResult>
pub async fn list_vnets( &self, resource_group_name: &str, ) -> Result<VirtualNetworkListResult>
Gets all virtual networks in a resource group.
Sourcepub async fn list_vnets_all(&self) -> Result<VirtualNetworkListResult>
pub async fn list_vnets_all(&self) -> Result<VirtualNetworkListResult>
Gets all virtual networks in the subscription.
Sourcepub async fn get_vnet(
&self,
resource_group_name: &str,
vnet_name: &str,
) -> Result<VirtualNetwork>
pub async fn get_vnet( &self, resource_group_name: &str, vnet_name: &str, ) -> Result<VirtualNetwork>
Gets the specified virtual network.
Sourcepub async fn create_vnet(
&self,
resource_group_name: &str,
vnet_name: &str,
body: &VirtualNetworkCreateRequest,
) -> Result<VirtualNetwork>
pub async fn create_vnet( &self, resource_group_name: &str, vnet_name: &str, body: &VirtualNetworkCreateRequest, ) -> Result<VirtualNetwork>
Creates or updates a virtual network.
Sourcepub async fn delete_vnet(
&self,
resource_group_name: &str,
vnet_name: &str,
) -> Result<()>
pub async fn delete_vnet( &self, resource_group_name: &str, vnet_name: &str, ) -> Result<()>
Deletes the specified virtual network.
Sourcepub async fn list_subnets(
&self,
resource_group_name: &str,
vnet_name: &str,
) -> Result<SubnetListResult>
pub async fn list_subnets( &self, resource_group_name: &str, vnet_name: &str, ) -> Result<SubnetListResult>
Gets all subnets in a virtual network.
Sourcepub async fn get_subnet(
&self,
resource_group_name: &str,
vnet_name: &str,
subnet_name: &str,
) -> Result<Subnet>
pub async fn get_subnet( &self, resource_group_name: &str, vnet_name: &str, subnet_name: &str, ) -> Result<Subnet>
Gets the specified subnet.
Sourcepub async fn list_nsgs(
&self,
resource_group_name: &str,
) -> Result<NetworkSecurityGroupListResult>
pub async fn list_nsgs( &self, resource_group_name: &str, ) -> Result<NetworkSecurityGroupListResult>
Gets all network security groups in a resource group.
Sourcepub async fn list_nsgs_all(&self) -> Result<NetworkSecurityGroupListResult>
pub async fn list_nsgs_all(&self) -> Result<NetworkSecurityGroupListResult>
Gets all network security groups in the subscription.
Sourcepub async fn get_nsg(
&self,
resource_group_name: &str,
nsg_name: &str,
) -> Result<NetworkSecurityGroup>
pub async fn get_nsg( &self, resource_group_name: &str, nsg_name: &str, ) -> Result<NetworkSecurityGroup>
Gets the specified network security group.
Sourcepub async fn create_nsg(
&self,
resource_group_name: &str,
nsg_name: &str,
body: &NetworkSecurityGroupCreateRequest,
) -> Result<NetworkSecurityGroup>
pub async fn create_nsg( &self, resource_group_name: &str, nsg_name: &str, body: &NetworkSecurityGroupCreateRequest, ) -> Result<NetworkSecurityGroup>
Creates or updates a network security group.
Sourcepub async fn delete_nsg(
&self,
resource_group_name: &str,
nsg_name: &str,
) -> Result<()>
pub async fn delete_nsg( &self, resource_group_name: &str, nsg_name: &str, ) -> Result<()>
Deletes the specified network security group.
Sourcepub async fn list_security_rules(
&self,
resource_group_name: &str,
nsg_name: &str,
) -> Result<SecurityRuleListResult>
pub async fn list_security_rules( &self, resource_group_name: &str, nsg_name: &str, ) -> Result<SecurityRuleListResult>
Gets all security rules in a network security group.
Sourcepub async fn get_security_rule(
&self,
resource_group_name: &str,
nsg_name: &str,
rule_name: &str,
) -> Result<SecurityRule>
pub async fn get_security_rule( &self, resource_group_name: &str, nsg_name: &str, rule_name: &str, ) -> Result<SecurityRule>
Gets the specified network security rule.
Sourcepub async fn create_security_rule(
&self,
resource_group_name: &str,
nsg_name: &str,
rule_name: &str,
body: &SecurityRule,
) -> Result<SecurityRule>
pub async fn create_security_rule( &self, resource_group_name: &str, nsg_name: &str, rule_name: &str, body: &SecurityRule, ) -> Result<SecurityRule>
Creates or updates a security rule in a network security group.
Sourcepub async fn delete_security_rule(
&self,
resource_group_name: &str,
nsg_name: &str,
rule_name: &str,
) -> Result<()>
pub async fn delete_security_rule( &self, resource_group_name: &str, nsg_name: &str, rule_name: &str, ) -> Result<()>
Deletes the specified network security rule.
Sourcepub async fn list_load_balancers(
&self,
resource_group_name: &str,
) -> Result<LoadBalancerListResult>
pub async fn list_load_balancers( &self, resource_group_name: &str, ) -> Result<LoadBalancerListResult>
Gets all the load balancers in a resource group.
Sourcepub async fn list_load_balancers_all(&self) -> Result<LoadBalancerListResult>
pub async fn list_load_balancers_all(&self) -> Result<LoadBalancerListResult>
Gets all the load balancers in the subscription.
Sourcepub async fn get_load_balancer(
&self,
resource_group_name: &str,
lb_name: &str,
) -> Result<LoadBalancer>
pub async fn get_load_balancer( &self, resource_group_name: &str, lb_name: &str, ) -> Result<LoadBalancer>
Gets the specified load balancer.
Sourcepub async fn create_load_balancer(
&self,
resource_group_name: &str,
lb_name: &str,
body: &LoadBalancerCreateRequest,
) -> Result<LoadBalancer>
pub async fn create_load_balancer( &self, resource_group_name: &str, lb_name: &str, body: &LoadBalancerCreateRequest, ) -> Result<LoadBalancer>
Creates or updates a load balancer.
Sourcepub async fn delete_load_balancer(
&self,
resource_group_name: &str,
lb_name: &str,
) -> Result<()>
pub async fn delete_load_balancer( &self, resource_group_name: &str, lb_name: &str, ) -> Result<()>
Deletes the specified load balancer.